@@ -68,8 +68,9 @@ MainWindow::MainWindow(QWidget *parent) :
     new Extensions(m_webView);
 
 #ifdef Q_WS_MAEMO_5
+    QString hybridUrl(qgetenv("HYBRID_URL").constData());
     //: locale selecting which language-version of the Hybrid app is being loaded on startup (currently 'en_US' and 'nl_NL' are supported only)
-    m_webView->load(QUrl("http://www.hyves.nl/hybrid/?&locale=" + tr("en_US")));
+    m_webView->load(QUrl(hybridUrl.isEmpty() ? "http://www.hyves.nl/hybrid/?&locale=" + tr("en_US") : hybridUrl));
 #else
     QDir templateDir = QDir::current();
 #ifdef Q_WS_SIMULATOR
