@@ -15,8 +15,9 @@ class MainWindow : public QMainWindow {
 
 #ifdef Q_WS_MAEMO_5
     private slots:
+        void showAbout();
         void loadFinished(bool success = true);
-        void initialized();
+        void setDisplayOrientation(Qt::WidgetAttribute orientation);
 #endif
 
     private:
