@@ -12,6 +12,9 @@ class WebPage : public QWebPage {
         explicit WebPage(QObject *parent = 0);
 
     protected:
+#ifdef Q_WS_MAEMO_5
+        QString userAgentForUrl(const QUrl &url) const;
+#endif
         void javaScriptConsoleMessage(const QString &message, int lineNumber, const QString &sourceId);
 
         bool acceptNavigationRequest(QWebFrame *frame, const QNetworkRequest &request, NavigationType type);
